"""ens_scene module

The ens_scene module provides a proxy interface to EnSight ENS_SCENE instances

"""
from ansys.pyensight.core.session import Session
from ansys.pyensight.core.ensobj import ENSOBJ
from ansys.pyensight.core import ensobjlist
from typing import Any, Dict, List, Type, Union, Optional, Tuple, TYPE_CHECKING, cast

if TYPE_CHECKING:
    from ansys.api.pyensight.ensight_api import ENS_VAR, ENS_ANNOT, ENS_PALETTE, ENS_PART, ENS_SOURCE, ENS_CASE, ENS_QUERY, ENS_GROUP, ENS_TOOL, ENS_TEXTURE, ENS_VPORT, ENS_PLOTTER, ENS_POLYLINE, ENS_FRAME, ENS_PROBE, ENS_FLIPBOOK, ENS_LPART, ENS_STATE, ens_emitterobj

class ENS_SCENE(ENSOBJ):
    """This class acts as a proxy for the EnSight Python class ensight.objs.ENS_SCENE

    Args:
        \*args:
            Superclass (ENSOBJ) arguments
        \**kwargs:
            Superclass (ENSOBJ) keyword arguments

    """

    def __init__(self, *args, **kwargs) -> None:
        super().__init__(*args, **kwargs)
        self._update_attr_list(self._session, self._objid)

    @classmethod
    def _update_attr_list(cls, session: 'Session', id: int) -> None:
        if hasattr(cls, 'attr_list'):
            return
        cmd = session.remote_obj(id) + '.__ids__'
        cls.attr_list = session.cmd(cmd)

    @property
    def objid(self) -> int:  # noqa: N802
        """
        Return the EnSight object proxy ID (__OBJID__).
        """
        return self._objid

    def attrgroupinfo(self, *args, **kwargs) -> Any:
        """Get information about GUI groups for object attributes

        """
        arg_obj = f"{self._remote_obj()}"
        arg_list: List[str] = []
        for arg in args:
            arg_list.append(arg.__repr__())
        for key, value in kwargs.items():
            arg_list.append(f"{key}={value.__repr__()}")
        arg_string = ",".join(arg_list)
        cmd = f"{arg_obj}.attrgroupinfo({arg_string})"
        return self._session.cmd(cmd)

    @property
    def METADATA(self) -> Dict[Any, Any]:
        """METADATA property
        
        metadata
        
        Supported operations:
            getattr
        Datatype:
            CEI Metadata, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.METADATA)
        _value = cast(Dict[Any, Any], value)
        return _value

    @property
    def metadata(self) -> Dict[Any, Any]:
        """METADATA property
        
        metadata
        
        Supported operations:
            getattr
        Datatype:
            CEI Metadata, scalar
        
        Note: both 'metadata' and 'METADATA' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.METADATA)
        _value = cast(Dict[Any, Any], value)
        return _value

    @property
    def UUID(self) -> str:
        """UUID property
        
        universal unique id
        
        Supported operations:
            getattr
        Datatype:
            String, 37 characters maximum
        
        """
        value = self.getattr(self._session.ensight.objs.enums.UUID)
        _value = cast(str, value)
        return _value

    @property
    def uuid(self) -> str:
        """UUID property
        
        universal unique id
        
        Supported operations:
            getattr
        Datatype:
            String, 37 characters maximum
        
        Note: both 'uuid' and 'UUID' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.UUID)
        _value = cast(str, value)
        return _value

    @property
    def EDIT_TARGET(self) -> int:
        """EDIT_TARGET property
        
        currently an edit target
        
        Supported operations:
            getattr
        Datatype:
            Boolean, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.EDIT_TARGET)
        _value = cast(int, value)
        return _value

    @property
    def edit_target(self) -> int:
        """EDIT_TARGET property
        
        currently an edit target
        
        Supported operations:
            getattr
        Datatype:
            Boolean, scalar
        
        Note: both 'edit_target' and 'EDIT_TARGET' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.EDIT_TARGET)
        _value = cast(int, value)
        return _value

    @property
    def PROJECT_MASK(self) -> int:
        """PROJECT_MASK property
        
        object project mask
        
        Supported operations:
            getattr, setattr
        Datatype:
            64bit integer, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.PROJECT_MASK)
        _value = cast(int, value)
        return _value

    @PROJECT_MASK.setter
    def PROJECT_MASK(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.PROJECT_MASK, value)

    @property
    def project_mask(self) -> int:
        """PROJECT_MASK property
        
        object project mask
        
        Supported operations:
            getattr, setattr
        Datatype:
            64bit integer, scalar
        
        Note: both 'project_mask' and 'PROJECT_MASK' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.PROJECT_MASK)
        _value = cast(int, value)
        return _value

    @project_mask.setter
    def project_mask(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.PROJECT_MASK, value)

    @property
    def HANDLES_ENABLED(self) -> int:
        """Control the display and use of EnSight click and go handles for an object
        
        EnSight allows for direct interaction with many objects via click and go handles.
        The handles allow things like annotations and viewports to be moved or resized.
        They allow for the adjustment of values for clip planes and palette dynamic ranges.
        In some situations, allowing the user to directly adjust these values can be
        undesirable.  Setting this attribute to zero disables display of and interaction
        with click and go handles for the specific object instance.
        
        """
        value = self.getattr(self._session.ensight.objs.enums.HANDLES_ENABLED)
        _value = cast(int, value)
        return _value

    @HANDLES_ENABLED.setter
    def HANDLES_ENABLED(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.HANDLES_ENABLED, value)

    @property
    def handles_enabled(self) -> int:
        """Control the display and use of EnSight click and go handles for an object
        
        EnSight allows for direct interaction with many objects via click and go handles.
        The handles allow things like annotations and viewports to be moved or resized.
        They allow for the adjustment of values for clip planes and palette dynamic ranges.
        In some situations, allowing the user to directly adjust these values can be
        undesirable.  Setting this attribute to zero disables display of and interaction
        with click and go handles for the specific object instance.
        
        Note: both 'handles_enabled' and 'HANDLES_ENABLED' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.HANDLES_ENABLED)
        _value = cast(int, value)
        return _value

    @handles_enabled.setter
    def handles_enabled(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.HANDLES_ENABLED, value)

    @property
    def ACTIVE(self) -> int:
        """ACTIVE property
        
        scene active
        
        Supported operations:
            getattr, setattr
        Datatype:
            Boolean, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.ACTIVE)
        _value = cast(int, value)
        return _value

    @ACTIVE.setter
    def ACTIVE(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.ACTIVE, value)

    @property
    def active(self) -> int:
        """ACTIVE property
        
        scene active
        
        Supported operations:
            getattr, setattr
        Datatype:
            Boolean, scalar
        
        Note: both 'active' and 'ACTIVE' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.ACTIVE)
        _value = cast(int, value)
        return _value

    @active.setter
    def active(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.ACTIVE, value)

    @property
    def LOCATION(self) -> List[float]:
        """LOCATION property
        
        scene origin
        
        Supported operations:
            getattr, setattr
        Datatype:
            Float, 3 element array
        
        """
        value = self.getattr(self._session.ensight.objs.enums.LOCATION)
        _value = cast(List[float], value)
        return _value

    @LOCATION.setter
    def LOCATION(self, value: List[float]) -> None:
        self.setattr(self._session.ensight.objs.enums.LOCATION, value)

    @property
    def location(self) -> List[float]:
        """LOCATION property
        
        scene origin
        
        Supported operations:
            getattr, setattr
        Datatype:
            Float, 3 element array
        
        Note: both 'location' and 'LOCATION' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.LOCATION)
        _value = cast(List[float], value)
        return _value

    @location.setter
    def location(self, value: List[float]) -> None:
        self.setattr(self._session.ensight.objs.enums.LOCATION, value)

    @property
    def RADIUS(self) -> float:
        """RADIUS property
        
        scene radius
        
        Supported operations:
            getattr, setattr
        Datatype:
            Float, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.RADIUS)
        _value = cast(float, value)
        return _value

    @RADIUS.setter
    def RADIUS(self, value: float) -> None:
        self.setattr(self._session.ensight.objs.enums.RADIUS, value)

    @property
    def radius(self) -> float:
        """RADIUS property
        
        scene radius
        
        Supported operations:
            getattr, setattr
        Datatype:
            Float, scalar
        
        Note: both 'radius' and 'RADIUS' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.RADIUS)
        _value = cast(float, value)
        return _value

    @radius.setter
    def radius(self, value: float) -> None:
        self.setattr(self._session.ensight.objs.enums.RADIUS, value)

    @property
    def RADIUS_SCALE(self) -> float:
        """RADIUS_SCALE property
        
        scene radius scale
        
        Supported operations:
            getattr, setattr
        Datatype:
            Float, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.RADIUS_SCALE)
        _value = cast(float, value)
        return _value

    @RADIUS_SCALE.setter
    def RADIUS_SCALE(self, value: float) -> None:
        self.setattr(self._session.ensight.objs.enums.RADIUS_SCALE, value)

    @property
    def radius_scale(self) -> float:
        """RADIUS_SCALE property
        
        scene radius scale
        
        Supported operations:
            getattr, setattr
        Datatype:
            Float, scalar
        
        Note: both 'radius_scale' and 'RADIUS_SCALE' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.RADIUS_SCALE)
        _value = cast(float, value)
        return _value

    @radius_scale.setter
    def radius_scale(self, value: float) -> None:
        self.setattr(self._session.ensight.objs.enums.RADIUS_SCALE, value)

    @property
    def LIGHT_ENV_TEXNUM(self) -> int:
        """LIGHT_ENV_TEXNUM property
        
        for environment light source: index of HDR images
        
        Supported operations:
            getattr, setattr
        Datatype:
            Integer, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.LIGHT_ENV_TEXNUM)
        _value = cast(int, value)
        return _value

    @LIGHT_ENV_TEXNUM.setter
    def LIGHT_ENV_TEXNUM(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.LIGHT_ENV_TEXNUM, value)

    @property
    def light_env_texnum(self) -> int:
        """LIGHT_ENV_TEXNUM property
        
        for environment light source: index of HDR images
        
        Supported operations:
            getattr, setattr
        Datatype:
            Integer, scalar
        
        Note: both 'light_env_texnum' and 'LIGHT_ENV_TEXNUM' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.LIGHT_ENV_TEXNUM)
        _value = cast(int, value)
        return _value

    @light_env_texnum.setter
    def light_env_texnum(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.LIGHT_ENV_TEXNUM, value)

    @property
    def SHOW_LOCATION(self) -> int:
        """SHOW_LOCATION property
        
        show scene's center location
        
        Supported operations:
            getattr, setattr
        Datatype:
            Boolean, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.SHOW_LOCATION)
        _value = cast(int, value)
        return _value

    @SHOW_LOCATION.setter
    def SHOW_LOCATION(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.SHOW_LOCATION, value)

    @property
    def show_location(self) -> int:
        """SHOW_LOCATION property
        
        show scene's center location
        
        Supported operations:
            getattr, setattr
        Datatype:
            Boolean, scalar
        
        Note: both 'show_location' and 'SHOW_LOCATION' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.SHOW_LOCATION)
        _value = cast(int, value)
        return _value

    @show_location.setter
    def show_location(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.SHOW_LOCATION, value)

    @property
    def GROUND_ACTIVE(self) -> int:
        """GROUND_ACTIVE property
        
        show ground plane
        
        Supported operations:
            getattr, setattr
        Datatype:
            Boolean, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.GROUND_ACTIVE)
        _value = cast(int, value)
        return _value

    @GROUND_ACTIVE.setter
    def GROUND_ACTIVE(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.GROUND_ACTIVE, value)

    @property
    def ground_active(self) -> int:
        """GROUND_ACTIVE property
        
        show ground plane
        
        Supported operations:
            getattr, setattr
        Datatype:
            Boolean, scalar
        
        Note: both 'ground_active' and 'GROUND_ACTIVE' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.GROUND_ACTIVE)
        _value = cast(int, value)
        return _value

    @ground_active.setter
    def ground_active(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.GROUND_ACTIVE, value)

    @property
    def GROUND_UPDIR(self) -> int:
        """GROUND_UPDIR property
        
        ground plane's up vector enum
        
        Supported operations:
            getattr, setattr
        Datatype:
            Enum, scalar
        Enums:
            * ensight.objs.enums.UPVEC_X - x axis
            * ensight.objs.enums.UPVEC_NX - -x axis
            * ensight.objs.enums.UPVEC_Y - y axis
            * ensight.objs.enums.UPVEC_NY - -y axis
            * ensight.objs.enums.UPVEC_Z - z axis
            * ensight.objs.enums.UPVEC_NZ - -z axis
        
        """
        value = self.getattr(self._session.ensight.objs.enums.GROUND_UPDIR)
        _value = cast(int, value)
        return _value

    @GROUND_UPDIR.setter
    def GROUND_UPDIR(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.GROUND_UPDIR, value)

    @property
    def ground_updir(self) -> int:
        """GROUND_UPDIR property
        
        ground plane's up vector enum
        
        Supported operations:
            getattr, setattr
        Datatype:
            Enum, scalar
        Enums:
            * ensight.objs.enums.UPVEC_X - x axis
            * ensight.objs.enums.UPVEC_NX - -x axis
            * ensight.objs.enums.UPVEC_Y - y axis
            * ensight.objs.enums.UPVEC_NY - -y axis
            * ensight.objs.enums.UPVEC_Z - z axis
            * ensight.objs.enums.UPVEC_NZ - -z axis
        
        Note: both 'ground_updir' and 'GROUND_UPDIR' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.GROUND_UPDIR)
        _value = cast(int, value)
        return _value

    @ground_updir.setter
    def ground_updir(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.GROUND_UPDIR, value)

    @property
    def GROUND_BLENDSCALE(self) -> float:
        """GROUND_BLENDSCALE property
        
        ground plane's blending scale factor
        
        Supported operations:
            getattr, setattr
        Datatype:
            Float, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.GROUND_BLENDSCALE)
        _value = cast(float, value)
        return _value

    @GROUND_BLENDSCALE.setter
    def GROUND_BLENDSCALE(self, value: float) -> None:
        self.setattr(self._session.ensight.objs.enums.GROUND_BLENDSCALE, value)

    @property
    def ground_blendscale(self) -> float:
        """GROUND_BLENDSCALE property
        
        ground plane's blending scale factor
        
        Supported operations:
            getattr, setattr
        Datatype:
            Float, scalar
        
        Note: both 'ground_blendscale' and 'GROUND_BLENDSCALE' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.GROUND_BLENDSCALE)
        _value = cast(float, value)
        return _value

    @ground_blendscale.setter
    def ground_blendscale(self, value: float) -> None:
        self.setattr(self._session.ensight.objs.enums.GROUND_BLENDSCALE, value)

    @property
    def GROUND_TEXSCALE(self) -> float:
        """GROUND_TEXSCALE property
        
        ground plane's texture scale factor
        
        Supported operations:
            getattr, setattr
        Datatype:
            Float, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.GROUND_TEXSCALE)
        _value = cast(float, value)
        return _value

    @GROUND_TEXSCALE.setter
    def GROUND_TEXSCALE(self, value: float) -> None:
        self.setattr(self._session.ensight.objs.enums.GROUND_TEXSCALE, value)

    @property
    def ground_texscale(self) -> float:
        """GROUND_TEXSCALE property
        
        ground plane's texture scale factor
        
        Supported operations:
            getattr, setattr
        Datatype:
            Float, scalar
        
        Note: both 'ground_texscale' and 'GROUND_TEXSCALE' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.GROUND_TEXSCALE)
        _value = cast(float, value)
        return _value

    @ground_texscale.setter
    def ground_texscale(self, value: float) -> None:
        self.setattr(self._session.ensight.objs.enums.GROUND_TEXSCALE, value)

    @property
    def GROUND_GRIDSCALE(self) -> float:
        """GROUND_GRIDSCALE property
        
        ground plane's grid scale factor
        
        Supported operations:
            getattr, setattr
        Datatype:
            Float, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.GROUND_GRIDSCALE)
        _value = cast(float, value)
        return _value

    @GROUND_GRIDSCALE.setter
    def GROUND_GRIDSCALE(self, value: float) -> None:
        self.setattr(self._session.ensight.objs.enums.GROUND_GRIDSCALE, value)

    @property
    def ground_gridscale(self) -> float:
        """GROUND_GRIDSCALE property
        
        ground plane's grid scale factor
        
        Supported operations:
            getattr, setattr
        Datatype:
            Float, scalar
        
        Note: both 'ground_gridscale' and 'GROUND_GRIDSCALE' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.GROUND_GRIDSCALE)
        _value = cast(float, value)
        return _value

    @ground_gridscale.setter
    def ground_gridscale(self, value: float) -> None:
        self.setattr(self._session.ensight.objs.enums.GROUND_GRIDSCALE, value)

    @property
    def GROUND_COLOR(self) -> List[float]:
        """GROUND_COLOR property
        
        ground plane's color
        
        Supported operations:
            getattr, setattr
        Datatype:
            Float, 3 element array
        
        """
        value = self.getattr(self._session.ensight.objs.enums.GROUND_COLOR)
        _value = cast(List[float], value)
        return _value

    @GROUND_COLOR.setter
    def GROUND_COLOR(self, value: List[float]) -> None:
        self.setattr(self._session.ensight.objs.enums.GROUND_COLOR, value)

    @property
    def ground_color(self) -> List[float]:
        """GROUND_COLOR property
        
        ground plane's color
        
        Supported operations:
            getattr, setattr
        Datatype:
            Float, 3 element array
        
        Note: both 'ground_color' and 'GROUND_COLOR' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.GROUND_COLOR)
        _value = cast(List[float], value)
        return _value

    @ground_color.setter
    def ground_color(self, value: List[float]) -> None:
        self.setattr(self._session.ensight.objs.enums.GROUND_COLOR, value)

    @property
    def GROUND_GRIDCOLORA(self) -> List[float]:
        """GROUND_GRIDCOLORA property
        
        ground plane's gridcolor A
        
        Supported operations:
            getattr, setattr
        Datatype:
            Float, 3 element array
        
        """
        value = self.getattr(self._session.ensight.objs.enums.GROUND_GRIDCOLORA)
        _value = cast(List[float], value)
        return _value

    @GROUND_GRIDCOLORA.setter
    def GROUND_GRIDCOLORA(self, value: List[float]) -> None:
        self.setattr(self._session.ensight.objs.enums.GROUND_GRIDCOLORA, value)

    @property
    def ground_gridcolora(self) -> List[float]:
        """GROUND_GRIDCOLORA property
        
        ground plane's gridcolor A
        
        Supported operations:
            getattr, setattr
        Datatype:
            Float, 3 element array
        
        Note: both 'ground_gridcolora' and 'GROUND_GRIDCOLORA' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.GROUND_GRIDCOLORA)
        _value = cast(List[float], value)
        return _value

    @ground_gridcolora.setter
    def ground_gridcolora(self, value: List[float]) -> None:
        self.setattr(self._session.ensight.objs.enums.GROUND_GRIDCOLORA, value)

    @property
    def GROUND_GRIDCOLORB(self) -> List[float]:
        """GROUND_GRIDCOLORB property
        
        ground plane's gridcolor B
        
        Supported operations:
            getattr, setattr
        Datatype:
            Float, 3 element array
        
        """
        value = self.getattr(self._session.ensight.objs.enums.GROUND_GRIDCOLORB)
        _value = cast(List[float], value)
        return _value

    @GROUND_GRIDCOLORB.setter
    def GROUND_GRIDCOLORB(self, value: List[float]) -> None:
        self.setattr(self._session.ensight.objs.enums.GROUND_GRIDCOLORB, value)

    @property
    def ground_gridcolorb(self) -> List[float]:
        """GROUND_GRIDCOLORB property
        
        ground plane's gridcolor B
        
        Supported operations:
            getattr, setattr
        Datatype:
            Float, 3 element array
        
        Note: both 'ground_gridcolorb' and 'GROUND_GRIDCOLORB' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.GROUND_GRIDCOLORB)
        _value = cast(List[float], value)
        return _value

    @ground_gridcolorb.setter
    def ground_gridcolorb(self, value: List[float]) -> None:
        self.setattr(self._session.ensight.objs.enums.GROUND_GRIDCOLORB, value)

    @property
    def GROUND_HASREFL(self) -> int:
        """GROUND_HASREFL property
        
        ground plane receives reflection
        
        Supported operations:
            getattr, setattr
        Datatype:
            Boolean, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.GROUND_HASREFL)
        _value = cast(int, value)
        return _value

    @GROUND_HASREFL.setter
    def GROUND_HASREFL(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.GROUND_HASREFL, value)

    @property
    def ground_hasrefl(self) -> int:
        """GROUND_HASREFL property
        
        ground plane receives reflection
        
        Supported operations:
            getattr, setattr
        Datatype:
            Boolean, scalar
        
        Note: both 'ground_hasrefl' and 'GROUND_HASREFL' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.GROUND_HASREFL)
        _value = cast(int, value)
        return _value

    @ground_hasrefl.setter
    def ground_hasrefl(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.GROUND_HASREFL, value)

    @property
    def GROUND_HASSHADOW(self) -> int:
        """GROUND_HASSHADOW property
        
        ground plane receives shadow
        
        Supported operations:
            getattr, setattr
        Datatype:
            Boolean, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.GROUND_HASSHADOW)
        _value = cast(int, value)
        return _value

    @GROUND_HASSHADOW.setter
    def GROUND_HASSHADOW(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.GROUND_HASSHADOW, value)

    @property
    def ground_hasshadow(self) -> int:
        """GROUND_HASSHADOW property
        
        ground plane receives shadow
        
        Supported operations:
            getattr, setattr
        Datatype:
            Boolean, scalar
        
        Note: both 'ground_hasshadow' and 'GROUND_HASSHADOW' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.GROUND_HASSHADOW)
        _value = cast(int, value)
        return _value

    @ground_hasshadow.setter
    def ground_hasshadow(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.GROUND_HASSHADOW, value)

    @property
    def GROUND_LOCK(self) -> int:
        """GROUND_LOCK property
        
        ground plane lock plane parameters
        
        Supported operations:
            getattr, setattr
        Datatype:
            Boolean, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.GROUND_LOCK)
        _value = cast(int, value)
        return _value

    @GROUND_LOCK.setter
    def GROUND_LOCK(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.GROUND_LOCK, value)

    @property
    def ground_lock(self) -> int:
        """GROUND_LOCK property
        
        ground plane lock plane parameters
        
        Supported operations:
            getattr, setattr
        Datatype:
            Boolean, scalar
        
        Note: both 'ground_lock' and 'GROUND_LOCK' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.GROUND_LOCK)
        _value = cast(int, value)
        return _value

    @ground_lock.setter
    def ground_lock(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.GROUND_LOCK, value)

    @property
    def GROUND_HASTEXTURE(self) -> int:
        """GROUND_HASTEXTURE property
        
        ground plane has texture
        
        Supported operations:
            getattr, setattr
        Datatype:
            Boolean, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.GROUND_HASTEXTURE)
        _value = cast(int, value)
        return _value

    @GROUND_HASTEXTURE.setter
    def GROUND_HASTEXTURE(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.GROUND_HASTEXTURE, value)

    @property
    def ground_hastexture(self) -> int:
        """GROUND_HASTEXTURE property
        
        ground plane has texture
        
        Supported operations:
            getattr, setattr
        Datatype:
            Boolean, scalar
        
        Note: both 'ground_hastexture' and 'GROUND_HASTEXTURE' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.GROUND_HASTEXTURE)
        _value = cast(int, value)
        return _value

    @ground_hastexture.setter
    def ground_hastexture(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.GROUND_HASTEXTURE, value)

    @property
    def GROUND_HASGRID(self) -> int:
        """GROUND_HASGRID property
        
        ground plane has grid lines
        
        Supported operations:
            getattr, setattr
        Datatype:
            Boolean, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.GROUND_HASGRID)
        _value = cast(int, value)
        return _value

    @GROUND_HASGRID.setter
    def GROUND_HASGRID(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.GROUND_HASGRID, value)

    @property
    def ground_hasgrid(self) -> int:
        """GROUND_HASGRID property
        
        ground plane has grid lines
        
        Supported operations:
            getattr, setattr
        Datatype:
            Boolean, scalar
        
        Note: both 'ground_hasgrid' and 'GROUND_HASGRID' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.GROUND_HASGRID)
        _value = cast(int, value)
        return _value

    @ground_hasgrid.setter
    def ground_hasgrid(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.GROUND_HASGRID, value)

    @property
    def GROUND_HEIGHTOFFSET(self) -> float:
        """GROUND_HEIGHTOFFSET property
        
        ground plane's height offset
        
        Supported operations:
            getattr, setattr
        Datatype:
            Float, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.GROUND_HEIGHTOFFSET)
        _value = cast(float, value)
        return _value

    @GROUND_HEIGHTOFFSET.setter
    def GROUND_HEIGHTOFFSET(self, value: float) -> None:
        self.setattr(self._session.ensight.objs.enums.GROUND_HEIGHTOFFSET, value)

    @property
    def ground_heightoffset(self) -> float:
        """GROUND_HEIGHTOFFSET property
        
        ground plane's height offset
        
        Supported operations:
            getattr, setattr
        Datatype:
            Float, scalar
        
        Note: both 'ground_heightoffset' and 'GROUND_HEIGHTOFFSET' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.GROUND_HEIGHTOFFSET)
        _value = cast(float, value)
        return _value

    @ground_heightoffset.setter
    def ground_heightoffset(self, value: float) -> None:
        self.setattr(self._session.ensight.objs.enums.GROUND_HEIGHTOFFSET, value)

    @property
    def GROUND_SAVEDINFO(self) -> List[float]:
        """GROUND_SAVEDINFO property
        
        ground plane saved plane parameters
        
        Supported operations:
            getattr, setattr
        Datatype:
            Float, 160 element array
        
        """
        value = self.getattr(self._session.ensight.objs.enums.GROUND_SAVEDINFO)
        _value = cast(List[float], value)
        return _value

    @GROUND_SAVEDINFO.setter
    def GROUND_SAVEDINFO(self, value: List[float]) -> None:
        self.setattr(self._session.ensight.objs.enums.GROUND_SAVEDINFO, value)

    @property
    def ground_savedinfo(self) -> List[float]:
        """GROUND_SAVEDINFO property
        
        ground plane saved plane parameters
        
        Supported operations:
            getattr, setattr
        Datatype:
            Float, 160 element array
        
        Note: both 'ground_savedinfo' and 'GROUND_SAVEDINFO' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.GROUND_SAVEDINFO)
        _value = cast(List[float], value)
        return _value

    @ground_savedinfo.setter
    def ground_savedinfo(self, value: List[float]) -> None:
        self.setattr(self._session.ensight.objs.enums.GROUND_SAVEDINFO, value)

    @property
    def ENVMAP_SAVEDINFO(self) -> List[float]:
        """ENVMAP_SAVEDINFO property
        
        envmap saved rotation parameters
        
        Supported operations:
            getattr, setattr
        Datatype:
            Float, 64 element array
        
        """
        value = self.getattr(self._session.ensight.objs.enums.ENVMAP_SAVEDINFO)
        _value = cast(List[float], value)
        return _value

    @ENVMAP_SAVEDINFO.setter
    def ENVMAP_SAVEDINFO(self, value: List[float]) -> None:
        self.setattr(self._session.ensight.objs.enums.ENVMAP_SAVEDINFO, value)

    @property
    def envmap_savedinfo(self) -> List[float]:
        """ENVMAP_SAVEDINFO property
        
        envmap saved rotation parameters
        
        Supported operations:
            getattr, setattr
        Datatype:
            Float, 64 element array
        
        Note: both 'envmap_savedinfo' and 'ENVMAP_SAVEDINFO' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.ENVMAP_SAVEDINFO)
        _value = cast(List[float], value)
        return _value

    @envmap_savedinfo.setter
    def envmap_savedinfo(self, value: List[float]) -> None:
        self.setattr(self._session.ensight.objs.enums.ENVMAP_SAVEDINFO, value)



"""ens_camera module

The ens_camera module provides a proxy interface to EnSight ENS_CAMERA instances

"""
from ansys.pyensight.core.session import Session
from ansys.pyensight.core.ensobj import ENSOBJ
from ansys.pyensight.core import ensobjlist
from typing import Any, Dict, List, Type, Union, Optional, Tuple, TYPE_CHECKING, cast

if TYPE_CHECKING:
    from ansys.api.pyensight.ensight_api import ENS_VAR, ENS_ANNOT, ENS_PALETTE, ENS_PART, ENS_SOURCE, ENS_CASE, ENS_QUERY, ENS_GROUP, ENS_TOOL, ENS_TEXTURE, ENS_VPORT, ENS_PLOTTER, ENS_POLYLINE, ENS_FRAME, ENS_PROBE, ENS_FLIPBOOK, ENS_SCENE, ENS_LPART, ENS_STATE, ens_emitterobj

class ENS_CAMERA(ENSOBJ):
    """This class acts as a proxy for the EnSight Python class ensight.objs.ENS_CAMERA

    Args:
        \*args:
            Superclass (ENSOBJ) arguments
        \**kwargs:
            Superclass (ENSOBJ) keyword arguments

    """

    def __init__(self, *args, **kwargs) -> None:
        super().__init__(*args, **kwargs)
        self._update_attr_list(self._session, self._objid)

    @classmethod
    def _update_attr_list(cls, session: 'Session', id: int) -> None:
        if hasattr(cls, 'attr_list'):
            return
        cmd = session.remote_obj(id) + '.__ids__'
        cls.attr_list = session.cmd(cmd)

    @property
    def objid(self) -> int:  # noqa: N802
        """
        Return the EnSight object proxy ID (__OBJID__).
        """
        return self._objid

    def attrgroupinfo(self, *args, **kwargs) -> Any:
        """Get information about GUI groups for object attributes

        """
        arg_obj = f"{self._remote_obj()}"
        arg_list: List[str] = []
        for arg in args:
            arg_list.append(arg.__repr__())
        for key, value in kwargs.items():
            arg_list.append(f"{key}={value.__repr__()}")
        arg_string = ",".join(arg_list)
        cmd = f"{arg_obj}.attrgroupinfo({arg_string})"
        return self._session.cmd(cmd)

    @property
    def METADATA(self) -> Dict[Any, Any]:
        """METADATA property
        
        metadata
        
        Supported operations:
            getattr
        Datatype:
            CEI Metadata, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.METADATA)
        _value = cast(Dict[Any, Any], value)
        return _value

    @property
    def metadata(self) -> Dict[Any, Any]:
        """METADATA property
        
        metadata
        
        Supported operations:
            getattr
        Datatype:
            CEI Metadata, scalar
        
        Note: both 'metadata' and 'METADATA' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.METADATA)
        _value = cast(Dict[Any, Any], value)
        return _value

    @property
    def UUID(self) -> str:
        """UUID property
        
        universal unique id
        
        Supported operations:
            getattr
        Datatype:
            String, 37 characters maximum
        
        """
        value = self.getattr(self._session.ensight.objs.enums.UUID)
        _value = cast(str, value)
        return _value

    @property
    def uuid(self) -> str:
        """UUID property
        
        universal unique id
        
        Supported operations:
            getattr
        Datatype:
            String, 37 characters maximum
        
        Note: both 'uuid' and 'UUID' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.UUID)
        _value = cast(str, value)
        return _value

    @property
    def EDIT_TARGET(self) -> int:
        """EDIT_TARGET property
        
        currently an edit target
        
        Supported operations:
            getattr
        Datatype:
            Boolean, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.EDIT_TARGET)
        _value = cast(int, value)
        return _value

    @property
    def edit_target(self) -> int:
        """EDIT_TARGET property
        
        currently an edit target
        
        Supported operations:
            getattr
        Datatype:
            Boolean, scalar
        
        Note: both 'edit_target' and 'EDIT_TARGET' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.EDIT_TARGET)
        _value = cast(int, value)
        return _value

    @property
    def PROJECT_MASK(self) -> int:
        """PROJECT_MASK property
        
        object project mask
        
        Supported operations:
            getattr, setattr
        Datatype:
            64bit integer, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.PROJECT_MASK)
        _value = cast(int, value)
        return _value

    @PROJECT_MASK.setter
    def PROJECT_MASK(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.PROJECT_MASK, value)

    @property
    def project_mask(self) -> int:
        """PROJECT_MASK property
        
        object project mask
        
        Supported operations:
            getattr, setattr
        Datatype:
            64bit integer, scalar
        
        Note: both 'project_mask' and 'PROJECT_MASK' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.PROJECT_MASK)
        _value = cast(int, value)
        return _value

    @project_mask.setter
    def project_mask(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.PROJECT_MASK, value)

    @property
    def HANDLES_ENABLED(self) -> int:
        """Control the display and use of EnSight click and go handles for an object
        
        EnSight allows for direct interaction with many objects via click and go handles.
        The handles allow things like annotations and viewports to be moved or resized.
        They allow for the adjustment of values for clip planes and palette dynamic ranges.
        In some situations, allowing the user to directly adjust these values can be
        undesirable.  Setting this attribute to zero disables display of and interaction
        with click and go handles for the specific object instance.
        
        """
        value = self.getattr(self._session.ensight.objs.enums.HANDLES_ENABLED)
        _value = cast(int, value)
        return _value

    @HANDLES_ENABLED.setter
    def HANDLES_ENABLED(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.HANDLES_ENABLED, value)

    @property
    def handles_enabled(self) -> int:
        """Control the display and use of EnSight click and go handles for an object
        
        EnSight allows for direct interaction with many objects via click and go handles.
        The handles allow things like annotations and viewports to be moved or resized.
        They allow for the adjustment of values for clip planes and palette dynamic ranges.
        In some situations, allowing the user to directly adjust these values can be
        undesirable.  Setting this attribute to zero disables display of and interaction
        with click and go handles for the specific object instance.
        
        Note: both 'handles_enabled' and 'HANDLES_ENABLED' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.HANDLES_ENABLED)
        _value = cast(int, value)
        return _value

    @handles_enabled.setter
    def handles_enabled(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.HANDLES_ENABLED, value)

    @property
    def INDEX(self) -> int:
        """INDEX property
        
        index
        
        Supported operations:
            getattr
        Datatype:
            Integer, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.INDEX)
        _value = cast(int, value)
        return _value

    @property
    def index(self) -> int:
        """INDEX property
        
        index
        
        Supported operations:
            getattr
        Datatype:
            Integer, scalar
        
        Note: both 'index' and 'INDEX' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.INDEX)
        _value = cast(int, value)
        return _value

    @property
    def VISIBLE(self) -> int:
        """VISIBLE property
        
        visible
        
        Supported operations:
            getattr, setattr
        Datatype:
            Boolean, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.VISIBLE)
        _value = cast(int, value)
        return _value

    @VISIBLE.setter
    def VISIBLE(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.VISIBLE, value)

    @property
    def visible(self) -> int:
        """VISIBLE property
        
        visible
        
        Supported operations:
            getattr, setattr
        Datatype:
            Boolean, scalar
        
        Note: both 'visible' and 'VISIBLE' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.VISIBLE)
        _value = cast(int, value)
        return _value

    @visible.setter
    def visible(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.VISIBLE, value)

    @property
    def LENS(self) -> int:
        """LENS property
        
        lens type
        
        Supported operations:
            getattr, setattr
        Datatype:
            Enum, scalar
        Enums:
            * ensight.objs.enums.CAMERA_LENS_NORMAL - normal
            * ensight.objs.enums.CAMERA_LENS_VIEW_PYRAMID - view pyramid
        
        """
        value = self.getattr(self._session.ensight.objs.enums.LENS)
        _value = cast(int, value)
        return _value

    @LENS.setter
    def LENS(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.LENS, value)

    @property
    def lens(self) -> int:
        """LENS property
        
        lens type
        
        Supported operations:
            getattr, setattr
        Datatype:
            Enum, scalar
        Enums:
            * ensight.objs.enums.CAMERA_LENS_NORMAL - normal
            * ensight.objs.enums.CAMERA_LENS_VIEW_PYRAMID - view pyramid
        
        Note: both 'lens' and 'LENS' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.LENS)
        _value = cast(int, value)
        return _value

    @lens.setter
    def lens(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.LENS, value)

    @property
    def ANGLE(self) -> float:
        """ANGLE property
        
        perspective angle
        
        Supported operations:
            getattr, setattr
        Datatype:
            Float, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.ANGLE)
        _value = cast(float, value)
        return _value

    @ANGLE.setter
    def ANGLE(self, value: float) -> None:
        self.setattr(self._session.ensight.objs.enums.ANGLE, value)

    @property
    def angle(self) -> float:
        """ANGLE property
        
        perspective angle
        
        Supported operations:
            getattr, setattr
        Datatype:
            Float, scalar
        
        Note: both 'angle' and 'ANGLE' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.ANGLE)
        _value = cast(float, value)
        return _value

    @angle.setter
    def angle(self, value: float) -> None:
        self.setattr(self._session.ensight.objs.enums.ANGLE, value)

    @property
    def CLIP(self) -> int:
        """CLIP property
        
        view pyramid clipping
        
        Supported operations:
            getattr, setattr
        Datatype:
            Boolean, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.CLIP)
        _value = cast(int, value)
        return _value

    @CLIP.setter
    def CLIP(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.CLIP, value)

    @property
    def clip(self) -> int:
        """CLIP property
        
        view pyramid clipping
        
        Supported operations:
            getattr, setattr
        Datatype:
            Boolean, scalar
        
        Note: both 'clip' and 'CLIP' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.CLIP)
        _value = cast(int, value)
        return _value

    @clip.setter
    def clip(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.CLIP, value)

    @property
    def LOOKAT_OPTION(self) -> int:
        """LOOKAT_OPTION property
        
        lookat option
        
        Supported operations:
            getattr, setattr
        Datatype:
            Enum, scalar
        Enums:
            * ensight.objs.enums.CAMERA_LOOK_AT_FORWARD - forward
            * ensight.objs.enums.CAMERA_LOOK_AT_NODE - node
            * ensight.objs.enums.CAMERA_LOOK_AT_XYZ - xyz
            * ensight.objs.enums.CAMERA_LOOK_AT_SPLINE - spline
            * ensight.objs.enums.CAMERA_LOOK_AT_PLANE_TOOL - plane tool
        
        """
        value = self.getattr(self._session.ensight.objs.enums.LOOKAT_OPTION)
        _value = cast(int, value)
        return _value

    @LOOKAT_OPTION.setter
    def LOOKAT_OPTION(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.LOOKAT_OPTION, value)

    @property
    def lookat_option(self) -> int:
        """LOOKAT_OPTION property
        
        lookat option
        
        Supported operations:
            getattr, setattr
        Datatype:
            Enum, scalar
        Enums:
            * ensight.objs.enums.CAMERA_LOOK_AT_FORWARD - forward
            * ensight.objs.enums.CAMERA_LOOK_AT_NODE - node
            * ensight.objs.enums.CAMERA_LOOK_AT_XYZ - xyz
            * ensight.objs.enums.CAMERA_LOOK_AT_SPLINE - spline
            * ensight.objs.enums.CAMERA_LOOK_AT_PLANE_TOOL - plane tool
        
        Note: both 'lookat_option' and 'LOOKAT_OPTION' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.LOOKAT_OPTION)
        _value = cast(int, value)
        return _value

    @lookat_option.setter
    def lookat_option(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.LOOKAT_OPTION, value)

    @property
    def LOOKAT_PART_ID(self) -> int:
        """LOOKAT_PART_ID property
        
        lookat part id
        
        Supported operations:
            getattr, setattr
        Datatype:
            Integer, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.LOOKAT_PART_ID)
        _value = cast(int, value)
        return _value

    @LOOKAT_PART_ID.setter
    def LOOKAT_PART_ID(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.LOOKAT_PART_ID, value)

    @property
    def lookat_part_id(self) -> int:
        """LOOKAT_PART_ID property
        
        lookat part id
        
        Supported operations:
            getattr, setattr
        Datatype:
            Integer, scalar
        
        Note: both 'lookat_part_id' and 'LOOKAT_PART_ID' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.LOOKAT_PART_ID)
        _value = cast(int, value)
        return _value

    @lookat_part_id.setter
    def lookat_part_id(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.LOOKAT_PART_ID, value)

    @property
    def LOOKAT_NODE_ID(self) -> int:
        """LOOKAT_NODE_ID property
        
        lookat node id
        
        Supported operations:
            getattr, setattr
        Datatype:
            Integer, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.LOOKAT_NODE_ID)
        _value = cast(int, value)
        return _value

    @LOOKAT_NODE_ID.setter
    def LOOKAT_NODE_ID(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.LOOKAT_NODE_ID, value)

    @property
    def lookat_node_id(self) -> int:
        """LOOKAT_NODE_ID property
        
        lookat node id
        
        Supported operations:
            getattr, setattr
        Datatype:
            Integer, scalar
        
        Note: both 'lookat_node_id' and 'LOOKAT_NODE_ID' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.LOOKAT_NODE_ID)
        _value = cast(int, value)
        return _value

    @lookat_node_id.setter
    def lookat_node_id(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.LOOKAT_NODE_ID, value)

    @property
    def LOOKAT_SPLINE_ID(self) -> int:
        """LOOKAT_SPLINE_ID property
        
        lookat spline id
        
        Supported operations:
            getattr, setattr
        Datatype:
            Integer, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.LOOKAT_SPLINE_ID)
        _value = cast(int, value)
        return _value

    @LOOKAT_SPLINE_ID.setter
    def LOOKAT_SPLINE_ID(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.LOOKAT_SPLINE_ID, value)

    @property
    def lookat_spline_id(self) -> int:
        """LOOKAT_SPLINE_ID property
        
        lookat spline id
        
        Supported operations:
            getattr, setattr
        Datatype:
            Integer, scalar
        
        Note: both 'lookat_spline_id' and 'LOOKAT_SPLINE_ID' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.LOOKAT_SPLINE_ID)
        _value = cast(int, value)
        return _value

    @lookat_spline_id.setter
    def lookat_spline_id(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.LOOKAT_SPLINE_ID, value)

    @property
    def LOOKAT_SPLINE_VALUE(self) -> float:
        """LOOKAT_SPLINE_VALUE property
        
        lookat spline value
        
        Supported operations:
            getattr, setattr
        Datatype:
            Float, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.LOOKAT_SPLINE_VALUE)
        _value = cast(float, value)
        return _value

    @LOOKAT_SPLINE_VALUE.setter
    def LOOKAT_SPLINE_VALUE(self, value: float) -> None:
        self.setattr(self._session.ensight.objs.enums.LOOKAT_SPLINE_VALUE, value)

    @property
    def lookat_spline_value(self) -> float:
        """LOOKAT_SPLINE_VALUE property
        
        lookat spline value
        
        Supported operations:
            getattr, setattr
        Datatype:
            Float, scalar
        
        Note: both 'lookat_spline_value' and 'LOOKAT_SPLINE_VALUE' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.LOOKAT_SPLINE_VALUE)
        _value = cast(float, value)
        return _value

    @lookat_spline_value.setter
    def lookat_spline_value(self, value: float) -> None:
        self.setattr(self._session.ensight.objs.enums.LOOKAT_SPLINE_VALUE, value)

    @property
    def LOOKAT_XYZ(self) -> List[float]:
        """LOOKAT_XYZ property
        
        lookat location
        
        Supported operations:
            getattr, setattr
        Datatype:
            Float, 3 element array
        
        """
        value = self.getattr(self._session.ensight.objs.enums.LOOKAT_XYZ)
        _value = cast(List[float], value)
        return _value

    @LOOKAT_XYZ.setter
    def LOOKAT_XYZ(self, value: List[float]) -> None:
        self.setattr(self._session.ensight.objs.enums.LOOKAT_XYZ, value)

    @property
    def lookat_xyz(self) -> List[float]:
        """LOOKAT_XYZ property
        
        lookat location
        
        Supported operations:
            getattr, setattr
        Datatype:
            Float, 3 element array
        
        Note: both 'lookat_xyz' and 'LOOKAT_XYZ' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.LOOKAT_XYZ)
        _value = cast(List[float], value)
        return _value

    @lookat_xyz.setter
    def lookat_xyz(self, value: List[float]) -> None:
        self.setattr(self._session.ensight.objs.enums.LOOKAT_XYZ, value)

    @property
    def ORIGIN_OPTION(self) -> int:
        """ORIGIN_OPTION property
        
        origin option
        
        Supported operations:
            getattr, setattr
        Datatype:
            Enum, scalar
        Enums:
            * ensight.objs.enums.CAMERA_LOOK_FROM_NODE - node
            * ensight.objs.enums.CAMERA_LOOK_FROM_XYZ - xyz
            * ensight.objs.enums.CAMERA_LOOK_FROM_SPLINE - spline
            * ensight.objs.enums.CAMERA_LOOK_FROM_PLANE_TOOL - plane tool
        
        """
        value = self.getattr(self._session.ensight.objs.enums.ORIGIN_OPTION)
        _value = cast(int, value)
        return _value

    @ORIGIN_OPTION.setter
    def ORIGIN_OPTION(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.ORIGIN_OPTION, value)

    @property
    def origin_option(self) -> int:
        """ORIGIN_OPTION property
        
        origin option
        
        Supported operations:
            getattr, setattr
        Datatype:
            Enum, scalar
        Enums:
            * ensight.objs.enums.CAMERA_LOOK_FROM_NODE - node
            * ensight.objs.enums.CAMERA_LOOK_FROM_XYZ - xyz
            * ensight.objs.enums.CAMERA_LOOK_FROM_SPLINE - spline
            * ensight.objs.enums.CAMERA_LOOK_FROM_PLANE_TOOL - plane tool
        
        Note: both 'origin_option' and 'ORIGIN_OPTION' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.ORIGIN_OPTION)
        _value = cast(int, value)
        return _value

    @origin_option.setter
    def origin_option(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.ORIGIN_OPTION, value)

    @property
    def ORIGIN_PART_ID(self) -> int:
        """ORIGIN_PART_ID property
        
        origin part id
        
        Supported operations:
            getattr, setattr
        Datatype:
            Integer, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.ORIGIN_PART_ID)
        _value = cast(int, value)
        return _value

    @ORIGIN_PART_ID.setter
    def ORIGIN_PART_ID(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.ORIGIN_PART_ID, value)

    @property
    def origin_part_id(self) -> int:
        """ORIGIN_PART_ID property
        
        origin part id
        
        Supported operations:
            getattr, setattr
        Datatype:
            Integer, scalar
        
        Note: both 'origin_part_id' and 'ORIGIN_PART_ID' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.ORIGIN_PART_ID)
        _value = cast(int, value)
        return _value

    @origin_part_id.setter
    def origin_part_id(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.ORIGIN_PART_ID, value)

    @property
    def ORIGIN_NODE_ID(self) -> int:
        """ORIGIN_NODE_ID property
        
        origin node id
        
        Supported operations:
            getattr, setattr
        Datatype:
            Integer, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.ORIGIN_NODE_ID)
        _value = cast(int, value)
        return _value

    @ORIGIN_NODE_ID.setter
    def ORIGIN_NODE_ID(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.ORIGIN_NODE_ID, value)

    @property
    def origin_node_id(self) -> int:
        """ORIGIN_NODE_ID property
        
        origin node id
        
        Supported operations:
            getattr, setattr
        Datatype:
            Integer, scalar
        
        Note: both 'origin_node_id' and 'ORIGIN_NODE_ID' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.ORIGIN_NODE_ID)
        _value = cast(int, value)
        return _value

    @origin_node_id.setter
    def origin_node_id(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.ORIGIN_NODE_ID, value)

    @property
    def ORIGIN_SPLINE_ID(self) -> int:
        """ORIGIN_SPLINE_ID property
        
        origin spline id
        
        Supported operations:
            getattr, setattr
        Datatype:
            Integer, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.ORIGIN_SPLINE_ID)
        _value = cast(int, value)
        return _value

    @ORIGIN_SPLINE_ID.setter
    def ORIGIN_SPLINE_ID(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.ORIGIN_SPLINE_ID, value)

    @property
    def origin_spline_id(self) -> int:
        """ORIGIN_SPLINE_ID property
        
        origin spline id
        
        Supported operations:
            getattr, setattr
        Datatype:
            Integer, scalar
        
        Note: both 'origin_spline_id' and 'ORIGIN_SPLINE_ID' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.ORIGIN_SPLINE_ID)
        _value = cast(int, value)
        return _value

    @origin_spline_id.setter
    def origin_spline_id(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.ORIGIN_SPLINE_ID, value)

    @property
    def ORIGIN_SPLINE_VALUE(self) -> float:
        """ORIGIN_SPLINE_VALUE property
        
        origin spline value
        
        Supported operations:
            getattr, setattr
        Datatype:
            Float, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.ORIGIN_SPLINE_VALUE)
        _value = cast(float, value)
        return _value

    @ORIGIN_SPLINE_VALUE.setter
    def ORIGIN_SPLINE_VALUE(self, value: float) -> None:
        self.setattr(self._session.ensight.objs.enums.ORIGIN_SPLINE_VALUE, value)

    @property
    def origin_spline_value(self) -> float:
        """ORIGIN_SPLINE_VALUE property
        
        origin spline value
        
        Supported operations:
            getattr, setattr
        Datatype:
            Float, scalar
        
        Note: both 'origin_spline_value' and 'ORIGIN_SPLINE_VALUE' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.ORIGIN_SPLINE_VALUE)
        _value = cast(float, value)
        return _value

    @origin_spline_value.setter
    def origin_spline_value(self, value: float) -> None:
        self.setattr(self._session.ensight.objs.enums.ORIGIN_SPLINE_VALUE, value)

    @property
    def ORIGIN_XYZ_DELTA(self) -> List[float]:
        """ORIGIN_XYZ_DELTA property
        
        origin location delta
        
        Supported operations:
            getattr, setattr
        Datatype:
            Float, 3 element array
        
        """
        value = self.getattr(self._session.ensight.objs.enums.ORIGIN_XYZ_DELTA)
        _value = cast(List[float], value)
        return _value

    @ORIGIN_XYZ_DELTA.setter
    def ORIGIN_XYZ_DELTA(self, value: List[float]) -> None:
        self.setattr(self._session.ensight.objs.enums.ORIGIN_XYZ_DELTA, value)

    @property
    def origin_xyz_delta(self) -> List[float]:
        """ORIGIN_XYZ_DELTA property
        
        origin location delta
        
        Supported operations:
            getattr, setattr
        Datatype:
            Float, 3 element array
        
        Note: both 'origin_xyz_delta' and 'ORIGIN_XYZ_DELTA' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.ORIGIN_XYZ_DELTA)
        _value = cast(List[float], value)
        return _value

    @origin_xyz_delta.setter
    def origin_xyz_delta(self, value: List[float]) -> None:
        self.setattr(self._session.ensight.objs.enums.ORIGIN_XYZ_DELTA, value)

    @property
    def DISTANCE_SCALE(self) -> float:
        """DISTANCE_SCALE property
        
        distance scale
        
        Supported operations:
            getattr, setattr
        Datatype:
            Float, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.DISTANCE_SCALE)
        _value = cast(float, value)
        return _value

    @DISTANCE_SCALE.setter
    def DISTANCE_SCALE(self, value: float) -> None:
        self.setattr(self._session.ensight.objs.enums.DISTANCE_SCALE, value)

    @property
    def distance_scale(self) -> float:
        """DISTANCE_SCALE property
        
        distance scale
        
        Supported operations:
            getattr, setattr
        Datatype:
            Float, scalar
        
        Note: both 'distance_scale' and 'DISTANCE_SCALE' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.DISTANCE_SCALE)
        _value = cast(float, value)
        return _value

    @distance_scale.setter
    def distance_scale(self, value: float) -> None:
        self.setattr(self._session.ensight.objs.enums.DISTANCE_SCALE, value)

    @property
    def DESCRIPTION(self) -> str:
        """DESCRIPTION property
        
        description
        
        Supported operations:
            getattr, setattr
        Datatype:
            String, 80 characters maximum
        
        """
        value = self.getattr(self._session.ensight.objs.enums.DESCRIPTION)
        _value = cast(str, value)
        return _value

    @DESCRIPTION.setter
    def DESCRIPTION(self, value: str) -> None:
        self.setattr(self._session.ensight.objs.enums.DESCRIPTION, value)

    @property
    def description(self) -> str:
        """DESCRIPTION property
        
        description
        
        Supported operations:
            getattr, setattr
        Datatype:
            String, 80 characters maximum
        
        Note: both 'description' and 'DESCRIPTION' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.DESCRIPTION)
        _value = cast(str, value)
        return _value

    @description.setter
    def description(self, value: str) -> None:
        self.setattr(self._session.ensight.objs.enums.DESCRIPTION, value)

    @property
    def SELECTED(self) -> int:
        """SELECTED property
        
        selected
        
        Supported operations:
            getattr, setattr
        Datatype:
            Boolean, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.SELECTED)
        _value = cast(int, value)
        return _value

    @SELECTED.setter
    def SELECTED(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.SELECTED, value)

    @property
    def selected(self) -> int:
        """SELECTED property
        
        selected
        
        Supported operations:
            getattr, setattr
        Datatype:
            Boolean, scalar
        
        Note: both 'selected' and 'SELECTED' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.SELECTED)
        _value = cast(int, value)
        return _value

    @selected.setter
    def selected(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.SELECTED, value)

    @property
    def VIEWPORT_USE(self) -> List[int]:
        """VIEWPORT_USE property
        
        use in viewports
        
        Supported operations:
            getattr, setattr
        Datatype:
            Boolean, 16 element array
        
        """
        value = self.getattr(self._session.ensight.objs.enums.VIEWPORT_USE)
        _value = cast(List[int], value)
        return _value

    @VIEWPORT_USE.setter
    def VIEWPORT_USE(self, value: List[int]) -> None:
        self.setattr(self._session.ensight.objs.enums.VIEWPORT_USE, value)

    @property
    def viewport_use(self) -> List[int]:
        """VIEWPORT_USE property
        
        use in viewports
        
        Supported operations:
            getattr, setattr
        Datatype:
            Boolean, 16 element array
        
        Note: both 'viewport_use' and 'VIEWPORT_USE' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.VIEWPORT_USE)
        _value = cast(List[int], value)
        return _value

    @viewport_use.setter
    def viewport_use(self, value: List[int]) -> None:
        self.setattr(self._session.ensight.objs.enums.VIEWPORT_USE, value)

    @property
    def TOOL_ORIENTATION(self) -> List[float]:
        """TOOL_ORIENTATION property
        
        tool orientation
        
        Supported operations:
            getattr, setattr
        Datatype:
            Float, 9 element array
        
        """
        value = self.getattr(self._session.ensight.objs.enums.TOOL_ORIENTATION)
        _value = cast(List[float], value)
        return _value

    @TOOL_ORIENTATION.setter
    def TOOL_ORIENTATION(self, value: List[float]) -> None:
        self.setattr(self._session.ensight.objs.enums.TOOL_ORIENTATION, value)

    @property
    def tool_orientation(self) -> List[float]:
        """TOOL_ORIENTATION property
        
        tool orientation
        
        Supported operations:
            getattr, setattr
        Datatype:
            Float, 9 element array
        
        Note: both 'tool_orientation' and 'TOOL_ORIENTATION' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.TOOL_ORIENTATION)
        _value = cast(List[float], value)
        return _value

    @tool_orientation.setter
    def tool_orientation(self, value: List[float]) -> None:
        self.setattr(self._session.ensight.objs.enums.TOOL_ORIENTATION, value)



"""ens_tool_line module

The ens_tool_line module provides a proxy interface to EnSight ENS_TOOL_LINE instances

"""
from ansys.pyensight.core.session import Session
from ansys.pyensight.core.ensobj import ENSOBJ
from ansys.pyensight.core import ensobjlist
from ansys.api.pyensight.ens_tool import ENS_TOOL
from typing import Any, Dict, List, Type, Union, Optional, Tuple, TYPE_CHECKING, cast

if TYPE_CHECKING:
    from ansys.api.pyensight.ensight_api import ENS_VAR, ENS_ANNOT, ENS_PALETTE, ENS_PART, ENS_SOURCE, ENS_CASE, ENS_QUERY, ENS_GROUP, ENS_TOOL, ENS_TEXTURE, ENS_VPORT, ENS_PLOTTER, ENS_POLYLINE, ENS_FRAME, ENS_PROBE, ENS_FLIPBOOK, ENS_SCENE, ENS_LPART, ENS_STATE, ens_emitterobj

class ENS_TOOL_LINE(ENS_TOOL):
    """This class acts as a proxy for the EnSight Python class ensight.objs.ENS_TOOL

    Args:
        \*args:
            Superclass (ENS_TOOL) arguments
        \**kwargs:
            Superclass (ENS_TOOL) keyword arguments

    """

    def __init__(self, *args, **kwargs) -> None:
        super().__init__(*args, **kwargs)
        self._update_attr_list(self._session, self._objid)

    @classmethod
    def _update_attr_list(cls, session: 'Session', id: int) -> None:
        if hasattr(cls, 'attr_list'):
            return
        cmd = session.remote_obj(id) + '.__ids__'
        cls.attr_list = session.cmd(cmd)

    @property
    def objid(self) -> int:  # noqa: N802
        """
        Return the EnSight object proxy ID (__OBJID__).
        """
        return self._objid

    def attrgroupinfo(self, *args, **kwargs) -> Any:
        """Get information about GUI groups for this tool's attributes

        """
        arg_obj = f"{self._remote_obj()}"
        arg_list: List[str] = []
        for arg in args:
            arg_list.append(arg.__repr__())
        for key, value in kwargs.items():
            arg_list.append(f"{key}={value.__repr__()}")
        arg_string = ",".join(arg_list)
        cmd = f"{arg_obj}.attrgroupinfo({arg_string})"
        return self._session.cmd(cmd)

    def rawdata(self, *args, **kwargs) -> Any:
        """Get/set the tool location using the raw location form

        """
        arg_obj = f"{self._remote_obj()}"
        arg_list: List[str] = []
        for arg in args:
            arg_list.append(arg.__repr__())
        for key, value in kwargs.items():
            arg_list.append(f"{key}={value.__repr__()}")
        arg_string = ",".join(arg_list)
        cmd = f"{arg_obj}.rawdata({arg_string})"
        return self._session.cmd(cmd)

    def fit_to_selected(self, *args, **kwargs) -> Any:
        """Set the box tool to span the selected parts

        """
        arg_obj = f"{self._remote_obj()}"
        arg_list: List[str] = []
        for arg in args:
            arg_list.append(arg.__repr__())
        for key, value in kwargs.items():
            arg_list.append(f"{key}={value.__repr__()}")
        arg_string = ",".join(arg_list)
        cmd = f"{arg_obj}.fit_to_selected({arg_string})"
        return self._session.cmd(cmd)

    @property
    def METADATA(self) -> Dict[Any, Any]:
        """METADATA property
        
        metadata
        
        Supported operations:
            getattr
        Datatype:
            CEI Metadata, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.METADATA)
        _value = cast(Dict[Any, Any], value)
        return _value

    @property
    def metadata(self) -> Dict[Any, Any]:
        """METADATA property
        
        metadata
        
        Supported operations:
            getattr
        Datatype:
            CEI Metadata, scalar
        
        Note: both 'metadata' and 'METADATA' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.METADATA)
        _value = cast(Dict[Any, Any], value)
        return _value

    @property
    def UUID(self) -> str:
        """UUID property
        
        universal unique id
        
        Supported operations:
            getattr
        Datatype:
            String, 37 characters maximum
        
        """
        value = self.getattr(self._session.ensight.objs.enums.UUID)
        _value = cast(str, value)
        return _value

    @property
    def uuid(self) -> str:
        """UUID property
        
        universal unique id
        
        Supported operations:
            getattr
        Datatype:
            String, 37 characters maximum
        
        Note: both 'uuid' and 'UUID' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.UUID)
        _value = cast(str, value)
        return _value

    @property
    def EDIT_TARGET(self) -> int:
        """EDIT_TARGET property
        
        currently an edit target
        
        Supported operations:
            getattr
        Datatype:
            Boolean, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.EDIT_TARGET)
        _value = cast(int, value)
        return _value

    @property
    def edit_target(self) -> int:
        """EDIT_TARGET property
        
        currently an edit target
        
        Supported operations:
            getattr
        Datatype:
            Boolean, scalar
        
        Note: both 'edit_target' and 'EDIT_TARGET' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.EDIT_TARGET)
        _value = cast(int, value)
        return _value

    @property
    def PROJECT_MASK(self) -> int:
        """PROJECT_MASK property
        
        object project mask
        
        Supported operations:
            getattr, setattr
        Datatype:
            64bit integer, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.PROJECT_MASK)
        _value = cast(int, value)
        return _value

    @PROJECT_MASK.setter
    def PROJECT_MASK(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.PROJECT_MASK, value)

    @property
    def project_mask(self) -> int:
        """PROJECT_MASK property
        
        object project mask
        
        Supported operations:
            getattr, setattr
        Datatype:
            64bit integer, scalar
        
        Note: both 'project_mask' and 'PROJECT_MASK' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.PROJECT_MASK)
        _value = cast(int, value)
        return _value

    @project_mask.setter
    def project_mask(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.PROJECT_MASK, value)

    @property
    def HANDLES_ENABLED(self) -> int:
        """Control the display and use of EnSight click and go handles for an object
        
        EnSight allows for direct interaction with many objects via click and go handles.
        The handles allow things like annotations and viewports to be moved or resized.
        They allow for the adjustment of values for clip planes and palette dynamic ranges.
        In some situations, allowing the user to directly adjust these values can be
        undesirable.  Setting this attribute to zero disables display of and interaction
        with click and go handles for the specific object instance.
        
        """
        value = self.getattr(self._session.ensight.objs.enums.HANDLES_ENABLED)
        _value = cast(int, value)
        return _value

    @HANDLES_ENABLED.setter
    def HANDLES_ENABLED(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.HANDLES_ENABLED, value)

    @property
    def handles_enabled(self) -> int:
        """Control the display and use of EnSight click and go handles for an object
        
        EnSight allows for direct interaction with many objects via click and go handles.
        The handles allow things like annotations and viewports to be moved or resized.
        They allow for the adjustment of values for clip planes and palette dynamic ranges.
        In some situations, allowing the user to directly adjust these values can be
        undesirable.  Setting this attribute to zero disables display of and interaction
        with click and go handles for the specific object instance.
        
        Note: both 'handles_enabled' and 'HANDLES_ENABLED' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.HANDLES_ENABLED)
        _value = cast(int, value)
        return _value

    @handles_enabled.setter
    def handles_enabled(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.HANDLES_ENABLED, value)

    @property
    def TOOLTYPE(self) -> int:
        """TOOLTYPE property
        
        tool type
        
        Supported operations:
            getattr
        Datatype:
            Enum, scalar
        Enums:
            * ensight.objs.enums.TOOL_CURSOR - cursor tool
            * ensight.objs.enums.TOOL_LINE - line tool
            * ensight.objs.enums.TOOL_PLANE - plane tool
            * ensight.objs.enums.TOOL_BOX - box tool
            * ensight.objs.enums.TOOL_CYLINDER - cylinder tool
            * ensight.objs.enums.TOOL_CONE - cone tool
            * ensight.objs.enums.TOOL_SPHERE - sphere tool
            * ensight.objs.enums.TOOL_REVOLUTION - revolution tool
            * ensight.objs.enums.TOOL_USERDEFINED - userdefined tool
        
        """
        value = self.getattr(self._session.ensight.objs.enums.TOOLTYPE)
        _value = cast(int, value)
        return _value

    @property
    def tooltype(self) -> int:
        """TOOLTYPE property
        
        tool type
        
        Supported operations:
            getattr
        Datatype:
            Enum, scalar
        Enums:
            * ensight.objs.enums.TOOL_CURSOR - cursor tool
            * ensight.objs.enums.TOOL_LINE - line tool
            * ensight.objs.enums.TOOL_PLANE - plane tool
            * ensight.objs.enums.TOOL_BOX - box tool
            * ensight.objs.enums.TOOL_CYLINDER - cylinder tool
            * ensight.objs.enums.TOOL_CONE - cone tool
            * ensight.objs.enums.TOOL_SPHERE - sphere tool
            * ensight.objs.enums.TOOL_REVOLUTION - revolution tool
            * ensight.objs.enums.TOOL_USERDEFINED - userdefined tool
        
        Note: both 'tooltype' and 'TOOLTYPE' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.TOOLTYPE)
        _value = cast(int, value)
        return _value

    @property
    def INDEX(self) -> int:
        """INDEX property
        
        tool index
        
        Supported operations:
            getattr
        Datatype:
            Integer, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.INDEX)
        _value = cast(int, value)
        return _value

    @property
    def index(self) -> int:
        """INDEX property
        
        tool index
        
        Supported operations:
            getattr
        Datatype:
            Integer, scalar
        
        Note: both 'index' and 'INDEX' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.INDEX)
        _value = cast(int, value)
        return _value

    @property
    def SELECTED(self) -> int:
        """SELECTED property
        
        selected
        
        Supported operations:
            getattr, setattr
        Datatype:
            Boolean, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.SELECTED)
        _value = cast(int, value)
        return _value

    @SELECTED.setter
    def SELECTED(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.SELECTED, value)

    @property
    def selected(self) -> int:
        """SELECTED property
        
        selected
        
        Supported operations:
            getattr, setattr
        Datatype:
            Boolean, scalar
        
        Note: both 'selected' and 'SELECTED' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.SELECTED)
        _value = cast(int, value)
        return _value

    @selected.setter
    def selected(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.SELECTED, value)

    @property
    def DESCRIPTION(self) -> str:
        """DESCRIPTION property
        
        description
        
        Supported operations:
            getattr, setattr
        Datatype:
            String, 256 characters maximum
        
        """
        value = self.getattr(self._session.ensight.objs.enums.DESCRIPTION)
        _value = cast(str, value)
        return _value

    @DESCRIPTION.setter
    def DESCRIPTION(self, value: str) -> None:
        self.setattr(self._session.ensight.objs.enums.DESCRIPTION, value)

    @property
    def description(self) -> str:
        """DESCRIPTION property
        
        description
        
        Supported operations:
            getattr, setattr
        Datatype:
            String, 256 characters maximum
        
        Note: both 'description' and 'DESCRIPTION' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.DESCRIPTION)
        _value = cast(str, value)
        return _value

    @description.setter
    def description(self, value: str) -> None:
        self.setattr(self._session.ensight.objs.enums.DESCRIPTION, value)

    @property
    def VISIBLE(self) -> int:
        """VISIBLE property
        
        visible
        
        Supported operations:
            getattr, setattr
        Datatype:
            Boolean, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.VISIBLE)
        _value = cast(int, value)
        return _value

    @VISIBLE.setter
    def VISIBLE(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.VISIBLE, value)

    @property
    def visible(self) -> int:
        """VISIBLE property
        
        visible
        
        Supported operations:
            getattr, setattr
        Datatype:
            Boolean, scalar
        
        Note: both 'visible' and 'VISIBLE' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.VISIBLE)
        _value = cast(int, value)
        return _value

    @visible.setter
    def visible(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.VISIBLE, value)

    @property
    def CORE(self) -> int:
        """CORE property
        
        core tool
        
        Supported operations:
            getattr
        Datatype:
            Boolean, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.CORE)
        _value = cast(int, value)
        return _value

    @property
    def core(self) -> int:
        """CORE property
        
        core tool
        
        Supported operations:
            getattr
        Datatype:
            Boolean, scalar
        
        Note: both 'core' and 'CORE' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.CORE)
        _value = cast(int, value)
        return _value

    @property
    def POINT1(self) -> List[float]:
        """POINT1 property
        
        start point
        
        Supported operations:
            getattr, setattr
        Datatype:
            Float, 3 element array
        
        """
        value = self.getattr(self._session.ensight.objs.enums.POINT1)
        _value = cast(List[float], value)
        return _value

    @POINT1.setter
    def POINT1(self, value: List[float]) -> None:
        self.setattr(self._session.ensight.objs.enums.POINT1, value)

    @property
    def point1(self) -> List[float]:
        """POINT1 property
        
        start point
        
        Supported operations:
            getattr, setattr
        Datatype:
            Float, 3 element array
        
        Note: both 'point1' and 'POINT1' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.POINT1)
        _value = cast(List[float], value)
        return _value

    @point1.setter
    def point1(self, value: List[float]) -> None:
        self.setattr(self._session.ensight.objs.enums.POINT1, value)

    @property
    def POINT2(self) -> List[float]:
        """POINT2 property
        
        end point
        
        Supported operations:
            getattr, setattr
        Datatype:
            Float, 3 element array
        
        """
        value = self.getattr(self._session.ensight.objs.enums.POINT2)
        _value = cast(List[float], value)
        return _value

    @POINT2.setter
    def POINT2(self, value: List[float]) -> None:
        self.setattr(self._session.ensight.objs.enums.POINT2, value)

    @property
    def point2(self) -> List[float]:
        """POINT2 property
        
        end point
        
        Supported operations:
            getattr, setattr
        Datatype:
            Float, 3 element array
        
        Note: both 'point2' and 'POINT2' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.POINT2)
        _value = cast(List[float], value)
        return _value

    @point2.setter
    def point2(self, value: List[float]) -> None:
        self.setattr(self._session.ensight.objs.enums.POINT2, value)

    @property
    def SNAP_SURF(self) -> int:
        """SNAP_SURF property
        
        snap to surface
        
        Supported operations:
            getattr, setattr
        Datatype:
            Boolean, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.SNAP_SURF)
        _value = cast(int, value)
        return _value

    @SNAP_SURF.setter
    def SNAP_SURF(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.SNAP_SURF, value)

    @property
    def snap_surf(self) -> int:
        """SNAP_SURF property
        
        snap to surface
        
        Supported operations:
            getattr, setattr
        Datatype:
            Boolean, scalar
        
        Note: both 'snap_surf' and 'SNAP_SURF' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.SNAP_SURF)
        _value = cast(int, value)
        return _value

    @snap_surf.setter
    def snap_surf(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.SNAP_SURF, value)

    @property
    def SNAP_NORM(self) -> int:
        """SNAP_NORM property
        
        snap normal direction
        
        Supported operations:
            getattr, setattr
        Datatype:
            Enum, scalar
        Enums:
            * ensight.objs.enums.POSITIVE_SURFACE_DIRECTION - positive
            * ensight.objs.enums.NEGATIVE_SURFACE_DIRECTION - negative
        
        """
        value = self.getattr(self._session.ensight.objs.enums.SNAP_NORM)
        _value = cast(int, value)
        return _value

    @SNAP_NORM.setter
    def SNAP_NORM(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.SNAP_NORM, value)

    @property
    def snap_norm(self) -> int:
        """SNAP_NORM property
        
        snap normal direction
        
        Supported operations:
            getattr, setattr
        Datatype:
            Enum, scalar
        Enums:
            * ensight.objs.enums.POSITIVE_SURFACE_DIRECTION - positive
            * ensight.objs.enums.NEGATIVE_SURFACE_DIRECTION - negative
        
        Note: both 'snap_norm' and 'SNAP_NORM' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.SNAP_NORM)
        _value = cast(int, value)
        return _value

    @snap_norm.setter
    def snap_norm(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.SNAP_NORM, value)



"""ens_texture module

The ens_texture module provides a proxy interface to EnSight ENS_TEXTURE instances

"""
from ansys.pyensight.core.session import Session
from ansys.pyensight.core.ensobj import ENSOBJ
from ansys.pyensight.core import ensobjlist
from typing import Any, Dict, List, Type, Union, Optional, Tuple, TYPE_CHECKING, cast

if TYPE_CHECKING:
    from ansys.api.pyensight.ensight_api import ENS_VAR, ENS_ANNOT, ENS_PALETTE, ENS_PART, ENS_SOURCE, ENS_CASE, ENS_QUERY, ENS_GROUP, ENS_TOOL, ENS_VPORT, ENS_PLOTTER, ENS_POLYLINE, ENS_FRAME, ENS_PROBE, ENS_FLIPBOOK, ENS_SCENE, ENS_LPART, ENS_STATE, ens_emitterobj

class ENS_TEXTURE(ENSOBJ):
    """This class acts as a proxy for the EnSight Python class ensight.objs.ENS_TEXTURE

    Args:
        \*args:
            Superclass (ENSOBJ) arguments
        \**kwargs:
            Superclass (ENSOBJ) keyword arguments

    """

    def __init__(self, *args, **kwargs) -> None:
        super().__init__(*args, **kwargs)
        self._update_attr_list(self._session, self._objid)

    @classmethod
    def _update_attr_list(cls, session: 'Session', id: int) -> None:
        if hasattr(cls, 'attr_list'):
            return
        cmd = session.remote_obj(id) + '.__ids__'
        cls.attr_list = session.cmd(cmd)

    @property
    def objid(self) -> int:  # noqa: N802
        """
        Return the EnSight object proxy ID (__OBJID__).
        """
        return self._objid

    def attrgroupinfo(self, *args, **kwargs) -> Any:
        """Get information about GUI groups for object attributes

        """
        arg_obj = f"{self._remote_obj()}"
        arg_list: List[str] = []
        for arg in args:
            arg_list.append(arg.__repr__())
        for key, value in kwargs.items():
            arg_list.append(f"{key}={value.__repr__()}")
        arg_string = ",".join(arg_list)
        cmd = f"{arg_obj}.attrgroupinfo({arg_string})"
        return self._session.cmd(cmd)

    @property
    def METADATA(self) -> Dict[Any, Any]:
        """METADATA property
        
        metadata
        
        Supported operations:
            getattr
        Datatype:
            CEI Metadata, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.METADATA)
        _value = cast(Dict[Any, Any], value)
        return _value

    @property
    def metadata(self) -> Dict[Any, Any]:
        """METADATA property
        
        metadata
        
        Supported operations:
            getattr
        Datatype:
            CEI Metadata, scalar
        
        Note: both 'metadata' and 'METADATA' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.METADATA)
        _value = cast(Dict[Any, Any], value)
        return _value

    @property
    def UUID(self) -> str:
        """UUID property
        
        universal unique id
        
        Supported operations:
            getattr
        Datatype:
            String, 37 characters maximum
        
        """
        value = self.getattr(self._session.ensight.objs.enums.UUID)
        _value = cast(str, value)
        return _value

    @property
    def uuid(self) -> str:
        """UUID property
        
        universal unique id
        
        Supported operations:
            getattr
        Datatype:
            String, 37 characters maximum
        
        Note: both 'uuid' and 'UUID' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.UUID)
        _value = cast(str, value)
        return _value

    @property
    def EDIT_TARGET(self) -> int:
        """EDIT_TARGET property
        
        currently an edit target
        
        Supported operations:
            getattr
        Datatype:
            Boolean, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.EDIT_TARGET)
        _value = cast(int, value)
        return _value

    @property
    def edit_target(self) -> int:
        """EDIT_TARGET property
        
        currently an edit target
        
        Supported operations:
            getattr
        Datatype:
            Boolean, scalar
        
        Note: both 'edit_target' and 'EDIT_TARGET' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.EDIT_TARGET)
        _value = cast(int, value)
        return _value

    @property
    def PROJECT_MASK(self) -> int:
        """PROJECT_MASK property
        
        object project mask
        
        Supported operations:
            getattr, setattr
        Datatype:
            64bit integer, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.PROJECT_MASK)
        _value = cast(int, value)
        return _value

    @PROJECT_MASK.setter
    def PROJECT_MASK(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.PROJECT_MASK, value)

    @property
    def project_mask(self) -> int:
        """PROJECT_MASK property
        
        object project mask
        
        Supported operations:
            getattr, setattr
        Datatype:
            64bit integer, scalar
        
        Note: both 'project_mask' and 'PROJECT_MASK' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.PROJECT_MASK)
        _value = cast(int, value)
        return _value

    @project_mask.setter
    def project_mask(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.PROJECT_MASK, value)

    @property
    def HANDLES_ENABLED(self) -> int:
        """Control the display and use of EnSight click and go handles for an object
        
        EnSight allows for direct interaction with many objects via click and go handles.
        The handles allow things like annotations and viewports to be moved or resized.
        They allow for the adjustment of values for clip planes and palette dynamic ranges.
        In some situations, allowing the user to directly adjust these values can be
        undesirable.  Setting this attribute to zero disables display of and interaction
        with click and go handles for the specific object instance.
        
        """
        value = self.getattr(self._session.ensight.objs.enums.HANDLES_ENABLED)
        _value = cast(int, value)
        return _value

    @HANDLES_ENABLED.setter
    def HANDLES_ENABLED(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.HANDLES_ENABLED, value)

    @property
    def handles_enabled(self) -> int:
        """Control the display and use of EnSight click and go handles for an object
        
        EnSight allows for direct interaction with many objects via click and go handles.
        The handles allow things like annotations and viewports to be moved or resized.
        They allow for the adjustment of values for clip planes and palette dynamic ranges.
        In some situations, allowing the user to directly adjust these values can be
        undesirable.  Setting this attribute to zero disables display of and interaction
        with click and go handles for the specific object instance.
        
        Note: both 'handles_enabled' and 'HANDLES_ENABLED' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.HANDLES_ENABLED)
        _value = cast(int, value)
        return _value

    @handles_enabled.setter
    def handles_enabled(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.HANDLES_ENABLED, value)

    @property
    def FILENAME(self) -> str:
        """FILENAME property
        
        Filename
        
        Supported operations:
            getattr
        Datatype:
            String, 256 characters maximum
        
        """
        value = self.getattr(self._session.ensight.objs.enums.FILENAME)
        _value = cast(str, value)
        return _value

    @property
    def filename(self) -> str:
        """FILENAME property
        
        Filename
        
        Supported operations:
            getattr
        Datatype:
            String, 256 characters maximum
        
        Note: both 'filename' and 'FILENAME' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.FILENAME)
        _value = cast(str, value)
        return _value

    @property
    def IMAGE(self) -> object:
        """IMAGE property
        
        Texture image
        
        Supported operations:
            getattr, setattr
        Datatype:
            EnSight Object, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.IMAGE)
        _value = cast(object, value)
        return _value

    @IMAGE.setter
    def IMAGE(self, value: object) -> None:
        self.setattr(self._session.ensight.objs.enums.IMAGE, value)

    @property
    def image(self) -> object:
        """IMAGE property
        
        Texture image
        
        Supported operations:
            getattr, setattr
        Datatype:
            EnSight Object, scalar
        
        Note: both 'image' and 'IMAGE' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.IMAGE)
        _value = cast(object, value)
        return _value

    @image.setter
    def image(self, value: object) -> None:
        self.setattr(self._session.ensight.objs.enums.IMAGE, value)

    @property
    def COMPRESSION(self) -> int:
        """COMPRESSION property
        
        Compression
        
        Supported operations:
            getattr, setattr
        Datatype:
            Enum, scalar
        Enums:
            * ensight.objs.enums.COMPRESSION_NONE - None
            * ensight.objs.enums.COMPRESSION_RLE - RLE
            * ensight.objs.enums.COMPRESSION_GZ - GZ
            * ensight.objs.enums.COMPRESSION_JPEG - JPEG
        
        """
        value = self.getattr(self._session.ensight.objs.enums.COMPRESSION)
        _value = cast(int, value)
        return _value

    @COMPRESSION.setter
    def COMPRESSION(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.COMPRESSION, value)

    @property
    def compression(self) -> int:
        """COMPRESSION property
        
        Compression
        
        Supported operations:
            getattr, setattr
        Datatype:
            Enum, scalar
        Enums:
            * ensight.objs.enums.COMPRESSION_NONE - None
            * ensight.objs.enums.COMPRESSION_RLE - RLE
            * ensight.objs.enums.COMPRESSION_GZ - GZ
            * ensight.objs.enums.COMPRESSION_JPEG - JPEG
        
        Note: both 'compression' and 'COMPRESSION' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.COMPRESSION)
        _value = cast(int, value)
        return _value

    @compression.setter
    def compression(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.COMPRESSION, value)

    @property
    def NUMFRAMES(self) -> int:
        """NUMFRAMES property
        
        Number of frames in the texture
        
        Supported operations:
            getattr
        Datatype:
            Integer, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.NUMFRAMES)
        _value = cast(int, value)
        return _value

    @property
    def numframes(self) -> int:
        """NUMFRAMES property
        
        Number of frames in the texture
        
        Supported operations:
            getattr
        Datatype:
            Integer, scalar
        
        Note: both 'numframes' and 'NUMFRAMES' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.NUMFRAMES)
        _value = cast(int, value)
        return _value

    @property
    def CURRENTFRAME(self) -> int:
        """CURRENTFRAME property
        
        Current texture frame number
        
        Supported operations:
            getattr
        Datatype:
            Integer, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.CURRENTFRAME)
        _value = cast(int, value)
        return _value

    @property
    def currentframe(self) -> int:
        """CURRENTFRAME property
        
        Current texture frame number
        
        Supported operations:
            getattr
        Datatype:
            Integer, scalar
        
        Note: both 'currentframe' and 'CURRENTFRAME' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.CURRENTFRAME)
        _value = cast(int, value)
        return _value

    @property
    def HASTRANSPARENT(self) -> int:
        """HASTRANSPARENT property
        
        Texture has transparent colors
        
        Supported operations:
            getattr
        Datatype:
            Boolean, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.HASTRANSPARENT)
        _value = cast(int, value)
        return _value

    @property
    def hastransparent(self) -> int:
        """HASTRANSPARENT property
        
        Texture has transparent colors
        
        Supported operations:
            getattr
        Datatype:
            Boolean, scalar
        
        Note: both 'hastransparent' and 'HASTRANSPARENT' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.HASTRANSPARENT)
        _value = cast(int, value)
        return _value

    @property
    def FRAMES(self) -> List[int]:
        """FRAMES property
        
        Animation frame limits
        
        Supported operations:
            getattr, setattr
        Datatype:
            Integer, 2 element array
        
        """
        value = self.getattr(self._session.ensight.objs.enums.FRAMES)
        _value = cast(List[int], value)
        return _value

    @FRAMES.setter
    def FRAMES(self, value: List[int]) -> None:
        self.setattr(self._session.ensight.objs.enums.FRAMES, value)

    @property
    def frames(self) -> List[int]:
        """FRAMES property
        
        Animation frame limits
        
        Supported operations:
            getattr, setattr
        Datatype:
            Integer, 2 element array
        
        Note: both 'frames' and 'FRAMES' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.FRAMES)
        _value = cast(List[int], value)
        return _value

    @frames.setter
    def frames(self, value: List[int]) -> None:
        self.setattr(self._session.ensight.objs.enums.FRAMES, value)

    @property
    def TIMES(self) -> List[float]:
        """TIMES property
        
        Animation time limits
        
        Supported operations:
            getattr, setattr
        Datatype:
            Float, 2 element array
        
        """
        value = self.getattr(self._session.ensight.objs.enums.TIMES)
        _value = cast(List[float], value)
        return _value

    @TIMES.setter
    def TIMES(self, value: List[float]) -> None:
        self.setattr(self._session.ensight.objs.enums.TIMES, value)

    @property
    def times(self) -> List[float]:
        """TIMES property
        
        Animation time limits
        
        Supported operations:
            getattr, setattr
        Datatype:
            Float, 2 element array
        
        Note: both 'times' and 'TIMES' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.TIMES)
        _value = cast(List[float], value)
        return _value

    @times.setter
    def times(self, value: List[float]) -> None:
        self.setattr(self._session.ensight.objs.enums.TIMES, value)

    @property
    def AUTOSCALE(self) -> int:
        """AUTOSCALE property
        
        Autoscale time
        
        Supported operations:
            getattr, setattr
        Datatype:
            Boolean, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.AUTOSCALE)
        _value = cast(int, value)
        return _value

    @AUTOSCALE.setter
    def AUTOSCALE(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.AUTOSCALE, value)

    @property
    def autoscale(self) -> int:
        """AUTOSCALE property
        
        Autoscale time
        
        Supported operations:
            getattr, setattr
        Datatype:
            Boolean, scalar
        
        Note: both 'autoscale' and 'AUTOSCALE' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.AUTOSCALE)
        _value = cast(int, value)
        return _value

    @autoscale.setter
    def autoscale(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.AUTOSCALE, value)

    @property
    def BORDERCOLOR(self) -> List[float]:
        """BORDERCOLOR property
        
        Border color
        
        Supported operations:
            getattr, setattr
        Datatype:
            Color RGBA, 4 element array
        
        """
        value = self.getattr(self._session.ensight.objs.enums.BORDERCOLOR)
        _value = cast(List[float], value)
        return _value

    @BORDERCOLOR.setter
    def BORDERCOLOR(self, value: List[float]) -> None:
        self.setattr(self._session.ensight.objs.enums.BORDERCOLOR, value)

    @property
    def bordercolor(self) -> List[float]:
        """BORDERCOLOR property
        
        Border color
        
        Supported operations:
            getattr, setattr
        Datatype:
            Color RGBA, 4 element array
        
        Note: both 'bordercolor' and 'BORDERCOLOR' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.BORDERCOLOR)
        _value = cast(List[float], value)
        return _value

    @bordercolor.setter
    def bordercolor(self, value: List[float]) -> None:
        self.setattr(self._session.ensight.objs.enums.BORDERCOLOR, value)

    @property
    def ID(self) -> int:
        """ID property
        
        ID
        
        Supported operations:
            getattr
        Datatype:
            Integer, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.ID)
        _value = cast(int, value)
        return _value

    @property
    def id(self) -> int:
        """ID property
        
        ID
        
        Supported operations:
            getattr
        Datatype:
            Integer, scalar
        
        Note: both 'id' and 'ID' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.ID)
        _value = cast(int, value)
        return _value
